tuplettools.change_augmented_tuplets_in_expr_to_diminished
==========================================================

.. autofunction:: abjad.tools.tuplettools.change_augmented_tuplets_in_expr_to_diminished.change_augmented_tuplets_in_expr_to_diminished
